@@ -1,6 +1,12 @@
 import {ThemeOptions} from '@mui/material'
 
 
+export const primaryColor = '#0070f0'
+export const secondaryColor = '#dd2f00'
+export const disabledColor = '#00000044'
+export const hintColor = '#4488ff'
+
+
 interface WorkspaceTheme extends ThemeOptions {
   notifications: {
     success: string
@@ -32,10 +38,10 @@ export const breakpoints: ThemeBreakpoints = {
 export const workspaceTheme: WorkspaceTheme = {
   palette: {
     primary: {
-      main: '#0070f0'
+      main: primaryColor
     },
     secondary: {
-      main: '#dd2f00'
+      main: secondaryColor
     }
   },
 
@@ -72,7 +78,7 @@ export const workspaceTheme: WorkspaceTheme = {
       styleOverrides: {
         root: {
           display: 'flex',
-          borderRadius: '5px',
+          borderRadius: '6px',
           zIndex: 1201,
           maxWidth: '19vw',
           // marginLeft: '-.5vmax',
