@@ -1,8 +1,8 @@
 """ A shortcut for making all targets in the order they best to be made. """
 
 from typing import *
+from types import ModuleType
 import asyncio
-import types
 import importlib
 from ...tools import CSTYLE
 from ... import config, logger
@@ -25,7 +25,7 @@ async def run(roots: List[str]) -> None:
     for target in ALL_TARGETS:
         logger.info(f"making the target: {CSTYLE['bold']}{target}{CSTYLE['clear']}", 'make')
         try:
-            target_module: types.ModuleType = importlib.import_module('.'.join([config.COREPKG, 'manage', 'targets', target]))
+            target_module: ModuleType = importlib.import_module('.'.join([config.COREPKG, 'manage', 'targets', target]))
 
         except ModuleNotFoundError as exc:
             raise RuntimeError(
